Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(285)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java

Issue 1809203006: Switch to use download GUID to indentify download items (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix merge error Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java b/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java
index d75619db73f2a3c090f535693a7391fcc2bcfac2..4c16ae45ed9224cec3258d6a19ef7dcd289c0323 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadNotifier.java
@@ -43,9 +43,9 @@ public interface DownloadNotifier {
/**
* Cancel the notification for a download.
* @param downloadId the downloadId of the cancelled download.
*/
- void cancelNotification(int downloadId);
+ void cancelNotification(int notificationId);
/**
* Called to clear all the pending download entries in SharedPreferences.
@@ -43,9 +43,9 @@ public interface DownloadNotifier {
/**
* Cancel the notification for a download.
- * @param downloadId the downloadId of the cancelled download.
+ * @param notificationId The notification ID of the cancelled download.
*/

Powered by Google App Engine
This is Rietveld 408576698